"""Smoke tests for ultra-quick validation of Rxiv-Maker functionality.

Smoke tests are designed to run in under 30 seconds and validate that core
functionality is working without running expensive operations like full
PDF generation or container operations.
"""
